@@ -2,10 +2,10 @@ package Clustericious::Config;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 
 # ABSTRACT: Configuration files for Clustericious nodes.
-our $VERSION = '0.9940_01'; # VERSION
+our $VERSION = '0.9940_02'; # VERSION
 
 
 use Clustericious::Config::Password;
@@ -229,7 +229,7 @@ Clustericious::Config - Configuration files for Clustericious nodes.
 
 =head1 VERSION
 
-version 0.9940_01
+version 0.9940_02
 
 =head1 SYNOPSIS
 
